@@ -64,6 +64,7 @@ class LutrisWindow(Gtk.ApplicationWindow):
     sync_button = GtkTemplate.Child()
     sync_label = GtkTemplate.Child()
     sync_spinner = GtkTemplate.Child()
+    search_spinner = GtkTemplate.Child()
     add_popover = GtkTemplate.Child()
     viewtype_icon = GtkTemplate.Child()
     website_search_toggle = GtkTemplate.Child()
@@ -95,7 +96,6 @@ class LutrisWindow(Gtk.ApplicationWindow):
 
         # Window initialization
         self.game_actions = GameActions(application=application, window=self)
-
         self.search_terms = None
         self.search_timer_id = None
         self.search_mode = "local"
@@ -105,6 +105,7 @@ class LutrisWindow(Gtk.ApplicationWindow):
         GObject.add_emission_hook(Game, "game-updated", self.on_game_updated)
         GObject.add_emission_hook(Game, "game-removed", self.on_game_updated)
         GObject.add_emission_hook(Game, "game-started", self.on_game_started)
+        GObject.add_emission_hook(Game, "game-installed", self.on_game_installed)
         GObject.add_emission_hook(
             GenericPanel, "running-game-selected", self.game_selection_changed
         )
@@ -219,12 +220,20 @@ class LutrisWindow(Gtk.ApplicationWindow):
             "use-dark-theme": Action(
                 self.on_dark_theme_state_change, type="b", default=self.use_dark_theme
             ),
+            "show-tray-icon": Action(
+                self.on_tray_icon_toggle, type="b", default=self.show_tray_icon
+            ),
             "show-left-side-panel": Action(
                 self.on_left_side_panel_state_change,
                 type="b",
                 default=self.left_side_panel_visible,
                 accel="F9",
             ),
+            "show-hidden-games": Action(
+                self.hidden_state_change,
+                type="b",
+                default=self.show_hidden_games,
+            ),
             "show-right-side-panel": Action(
                 self.on_right_side_panel_state_change,
                 type="b",
@@ -258,6 +267,45 @@ class LutrisWindow(Gtk.ApplicationWindow):
             if value.accel:
                 app.add_accelerator(value.accel, "win." + name)
 
+    def on_hide_game(self, _widget):
+        """Add a game to the list of hidden games"""
+        game = Game(self.view.selected_game)
+
+        # Append the new hidden ID and save it
+        ignores = pga.get_hidden_ids() + [game.id]
+        pga.set_hidden_ids(ignores)
+
+        # Update the GUI
+        if not self.show_hidden_games:
+            self.view.remove_game(game.id)
+
+    def on_unhide_game(self, _widget):
+        """Removes a game from the list of hidden games"""
+        game = Game(self.view.selected_game)
+
+        # Remove the ID to unhide and save it
+        ignores = pga.get_hidden_ids()
+        ignores.remove(game.id)
+        pga.set_hidden_ids(ignores)
+
+    def hidden_state_change(self, action, value):
+        """Hides or shows the hidden games"""
+        action.set_state(value)
+
+        # Add or remove hidden games
+        ignores = pga.get_hidden_ids()
+        settings.write_setting("show_hidden_games",
+                               str(self.show_hidden_games).lower(),
+                               section="lutris")
+
+        # If we have to show the hidden games now, we need to add them back to
+        # the view. If we need to hide them, we just remove them from the view
+        if value:
+            self.game_store.add_games_by_ids(ignores)
+        else:
+            for game_id in ignores:
+                self.game_store.remove_game(game_id)
+
     @property
     def current_view_type(self):
         """Returns which kind of view is currently presented (grid or list)"""
@@ -301,6 +349,17 @@ class LutrisWindow(Gtk.ApplicationWindow):
             == "true"
         )
 
+    def on_tray_icon_toggle(self, action, value):
+        """Callback for handling tray icon toggle"""
+        action.set_state(value)
+        settings.write_setting('show_tray_icon', value)
+        self.application.set_tray_icon()
+
+    @property
+    def show_tray_icon(self):
+        """Setting to hide or show status icon"""
+        return settings.read_setting("show_tray_icon", default="false").lower() == "true"
+
     @property
     def view_sorting(self):
         return settings.read_setting("view_sorting") or "name"
@@ -309,6 +368,10 @@ class LutrisWindow(Gtk.ApplicationWindow):
     def view_sorting_ascending(self):
         return settings.read_setting("view_sorting_ascending").lower() != "false"
 
+    @property
+    def show_hidden_games(self):
+        return settings.read_setting("show_hidden_games").lower() == "true"
+
     def get_store(self, games=None):
         """Return an instance of GameStore"""
         games = games or pga.get_games(show_installed_first=self.show_installed_first)
@@ -318,6 +381,7 @@ class LutrisWindow(Gtk.ApplicationWindow):
             self.filter_installed,
             self.view_sorting,
             self.view_sorting_ascending,
+            self.show_hidden_games,
             self.show_installed_first,
         )
         game_store.connect("sorting-changed", self.on_game_store_sorting_changed)
@@ -412,20 +476,6 @@ class LutrisWindow(Gtk.ApplicationWindow):
             lambda adj: self._set_icon_type(image_sizes[int(adj.props.value)]),
         )
 
-    @staticmethod
-    def check_update():
-        """Verify availability of client update."""
-        version_request = http.Request("https://lutris.net/version")
-        version_request.get()
-        version = version_request.content
-        if version:
-            latest_version = settings.read_setting("latest_version")
-            if version > (latest_version or settings.VERSION):
-                dialogs.ClientUpdateDialog()
-                # Store latest version seen to avoid showing
-                # the dialog more than once.
-                settings.write_setting("latest_version", version)
-
     def get_view_type(self):
         """Return the type of view saved by the user"""
         view_type = settings.read_setting("view_type")
@@ -531,7 +581,7 @@ class LutrisWindow(Gtk.ApplicationWindow):
     def open_sync_dialog(self):
         """Opens the service sync dialog"""
         self.add_popover.hide()
-        SyncServiceWindow(application=self.application)
+        self.application.show_window(SyncServiceWindow)
 
     def update_runtime(self):
         """Check that the runtime is up to date"""
@@ -563,8 +613,10 @@ class LutrisWindow(Gtk.ApplicationWindow):
         if game.is_installed:
             self.application.launch(game)
         else:
-            InstallerWindow(
-                parent=self, game_slug=game.slug, application=self.application,
+            self.application.show_window(
+                InstallerWindow,
+                parent=self,
+                game_slug=game.slug
             )
 
     @GtkTemplate.Callback
@@ -627,7 +679,7 @@ class LutrisWindow(Gtk.ApplicationWindow):
 
     @GtkTemplate.Callback
     def on_manage_runners(self, *args):
-        return RunnersDialog(transient_for=self)
+        self.application.show_window(RunnersDialog, transient_for=self)
 
     def invalidate_game_filter(self):
         """Refilter the game view based on current filters"""
@@ -665,10 +717,12 @@ class LutrisWindow(Gtk.ApplicationWindow):
             self.game_store.filter_text = entry.get_text()
             self.invalidate_game_filter()
         elif self.search_mode == "website":
+            search_terms = entry.get_text().lower().strip()
+            self.search_spinner.props.active = True
             if self.search_timer_id:
                 GLib.source_remove(self.search_timer_id)
             self.search_timer_id = GLib.timeout_add(
-                750, self.on_search_games_fire, entry.get_text().lower().strip()
+                750, self.on_search_games_fire, search_terms
             )
         else:
             raise ValueError("Unsupported search mode %s" % self.search_mode)
@@ -701,6 +755,7 @@ class LutrisWindow(Gtk.ApplicationWindow):
                 Gtk.EntryIconPosition.PRIMARY, "system-search-symbolic"
             )
             self.search_games("")
+            self.search_spinner.props.active = False
 
     @GtkTemplate.Callback
     def on_about_clicked(self, *_args):
@@ -712,6 +767,9 @@ class LutrisWindow(Gtk.ApplicationWindow):
         logger.error("%s crashed", game)
         dialogs.ErrorDialog(error, parent=self)
 
+    def on_game_installed(self, game):
+        self.game_selection_changed(None, game)
+
     def on_game_started(self, game):
         self.game_panel.refresh()
         return True
@@ -746,6 +804,7 @@ class LutrisWindow(Gtk.ApplicationWindow):
         self.game_store.set_icon_type(self.icon_type)
         self.game_store.load(from_search=bool(query))
         self.game_store.filter_text = self.search_entry.props.text
+        self.search_spinner.props.active = False
         self.switch_view(self.get_view_type())
         self.invalidate_game_filter()
 
