@@ -1,5 +1,6 @@
 """Manipulates installer files"""
 import os
+from urllib.parse import urlparse
 from lutris import pga
 from lutris import settings
 from lutris.installer.errors import ScriptingError, FileNotAvailable
@@ -30,10 +31,14 @@ class InstallerFile:
             self.referer = None
             self.checksum = None
 
+        if self.url.startswith(("$STEAM", "$WINESTEAM")):
+            self.filename = self.url
+
         if self.url.startswith("/"):
             self.url = "file://" + self.url
 
         if not self.filename:
+            logger.error("Couldn't find a filename for file %s in %s", file_id, file_meta)
             raise ScriptingError(
                 "No filename provided for %s, please provide 'url' "
                 "and 'filename' parameters in the script" % file_id
@@ -73,7 +78,8 @@ class InstallerFile:
         _cache_path = get_cache_path()
         if not _cache_path:
             _cache_path = os.path.join(settings.CACHE_DIR, "installer")
-        if "cdn.gog.com" in self.url or "cdn-hw.gog.com" in self.url:
+        url_parts = urlparse(self.url)
+        if url_parts.netloc.endswith("gog.com"):
             folder = "gog"
         else:
             folder = self.id
@@ -115,6 +121,7 @@ class InstallerFile:
             raise ScriptingError(hash_type.capitalize() + " checksum mismatch ", self.checksum)
 
     def download(self, downloader):
+        """Download a file with a given downloader"""
         if self.uses_pga_cache() and system.path_exists(self.dest_file):
             logger.info("File %s already cached", self)
             return False
