@@ -1,4 +1,3 @@
-# pylint: disable=E1101, E0611
 """Install a game by following its install script."""
 import os
 import time
@@ -27,10 +26,8 @@ from lutris.installer.commands import CommandsMixin
 from lutris.installer.installer_file import InstallerFile
 
 from lutris.services import UnavailableGame
-from lutris.services.gog import (
-    connect as connect_gog,
-    GogService,
-)
+from lutris.services.gog import get_gog_download_links, MultipleInstallerError
+from lutris.services.humblebundle import get_humble_download_link
 
 from lutris.runners import (
     wine,
@@ -114,7 +111,6 @@ class ScriptInterpreter(CommandsMixin):
         self.abort_current_task = None
         self.user_inputs = []
         self.steam_data = {}
-        self.gog_data = {}
         self.script = installer.get("script")
         if not self.script:
             raise ScriptingError("This installer doesn't have a 'script' section")
@@ -135,7 +131,9 @@ class ScriptInterpreter(CommandsMixin):
         self.game_name = self.script.get("custom-name") or installer["name"]
         self.game_slug = installer["game_slug"]
         self.steamid = installer.get("steamid")
-        self.gogid = installer.get("gogid")
+        game_config = self.script.get("game", {})
+        self.gogid = game_config.get("gogid") or installer.get("gogid")
+        self.humbleid = game_config.get("humbleid") or installer.get("humblestoreid")
 
         if not self.is_valid():
             raise ScriptingError(
@@ -184,7 +182,11 @@ class ScriptInterpreter(CommandsMixin):
         if self.runner in ("steam", "winesteam"):
             # Steam games installs in their steamapps directory
             return False
-        if self.files or self.script.get("game", {}).get("gog"):
+        if (
+                self.files
+                or self.script.get("game", {}).get("gog")
+                or self.script.get("game", {}).get("prefix")
+        ):
             return True
         command_names = [list(c.keys())[0] for c in self.script.get("installer", [])]
         if "insert-disc" in command_names:
@@ -224,6 +226,11 @@ class ScriptInterpreter(CommandsMixin):
             if "game" not in self.script or "core" not in self.script["game"]:
                 self.errors.append("Missing libretro core in game section")
 
+        # Check that Steam games have an AppID
+        if self.runner in ("steam", "winesteam"):
+            if not self.script.get("game", {}).get("appid"):
+                self.errors.append("Missing appid for Steam game")
+
         # Check that installers don't contain both 'requires' and 'extends'
         if self.script.get("requires") and self.script.get("extends"):
             self.errors.append("Scripts can't have both extends and requires")
@@ -286,8 +293,7 @@ class ScriptInterpreter(CommandsMixin):
                 if not installed_games:
                     if len(dependency) == 1:
                         raise MissingGameDependency(slug=dependency)
-                    else:
-                        raise ScriptingError(error_message.format(" or ".join(dependency)))
+                    raise ScriptingError(error_message.format(" or ".join(dependency)))
                 if index == 0:
                     self.target_path = installed_games[0]["directory"]
                     self.requires = installed_games[0]["installer_slug"]
@@ -302,54 +308,86 @@ class ScriptInterpreter(CommandsMixin):
     # ---------------------
     # "Get the files" stage
     # ---------------------
+    def pop_user_provided_file(self):
+        """Return and remove the first user provided file, which is used for game stores"""
+        installer_file_id = None
+        for index, file in enumerate(self.files):
+            if file.url.startswith("N/A"):
+                logger.debug("File %s detected as user provided, removing from files", file.id)
+                self.files.pop(index)
+                installer_file_id = file.id
+                break
+        return installer_file_id
 
     def swap_gog_game_files(self):
+        """Replace user provided file with downloads from GOG"""
         if not self.gogid:
             raise UnavailableGame("The installer has no GOG ID!")
         try:
-            links = self.get_gog_download_links()
+            links = get_gog_download_links(self.gogid, self.runner)
         except HTTPError:
             raise UnavailableGame("Couldn't load the download links for this game")
-        installer_file_id = None
-        if links:
-            for index, file in enumerate(self.files):
-                file_id = file.id
-                if file.url.startswith("N/A"):
-                    logger.debug("Removing file %s", file.id)
-                    self.files.pop(index)
-                    installer_file_id = file.id
-                    break
+        except MultipleInstallerError:
+            raise UnavailableGame("Don't know how to deal with multiple installers yet.")
+        if not links:
+            raise UnavailableGame("Could not fing GOG game")
 
+        installer_file_id = self.pop_user_provided_file()
         if not installer_file_id:
-            raise ScriptingError("Could not match a GOG installer file in the files")
+            raise UnavailableGame("Installer has no user provided file")
 
         file_id_provided = False  # Only assign installer_file_id once
         for index, link in enumerate(links):
-
-            filename = link.split("?")[0].split("/")[-1]
-
-            if filename.lower().endswith((".exe", ".sh")) and not file_id_provided:
+            if link["filename"].lower().endswith((".exe", ".sh")) and not file_id_provided:
                 file_id = installer_file_id
                 file_id_provided = True
             else:
                 file_id = "gog_file_%s" % index
-
-            logger.debug("Adding GOG file %s as %s", filename, file_id)
             self.files.append(
                 InstallerFile(self.game_slug, file_id, {
-                    "url": link,
-                    "filename": filename,
+                    "url": link["url"],
+                    "filename": link["filename"],
                 })
             )
 
+    def swap_humble_game_files(self):
+        """Replace the user provided file with download links from Humble Bundle"""
+        if not self.humbleid:
+            raise UnavailableGame(
+                "This installer has no Humble Bundle ID ('humbleid' in the game section)"
+            )
+        installer_file_id = self.pop_user_provided_file()
+        if not installer_file_id:
+            raise UnavailableGame("Installer has no user provided file")
+        try:
+            link = get_humble_download_link(self.humbleid, self.runner)
+        except Exception as ex:
+            logger.exception("Failed to get Humble Bundle game: %s", ex)
+            raise UnavailableGame
+        if not link:
+            raise UnavailableGame("No game found on Humble Bundle")
+        filename = link.split("?")[0].split("/")[-1]
+        self.files.append(
+            InstallerFile(self.game_slug, installer_file_id, {
+                "url": link,
+                "filename": filename
+            })
+        )
+
     def prepare_game_files(self):
         """Gathers necessary files before iterating through them."""
         # If this is a GOG installer, download required files.
-        if self.version.startswith("GOG"):
+        version = self.version.lower()
+        if version.startswith("gog"):
             try:
                 self.swap_gog_game_files()
             except UnavailableGame as ex:
                 logger.error("Unable to get the game from GOG: %s", ex)
+        if version.startswith("humble"):
+            try:
+                self.swap_humble_game_files()
+            except UnavailableGame as ex:
+                logger.error("Unable to get the game from GOG: %s", ex)
         self.iter_game_files()
 
     def iter_game_files(self):
@@ -449,12 +487,17 @@ class ScriptInterpreter(CommandsMixin):
                 version = self._get_runner_version()
                 if version:
                     params["version"] = version
-                elif runner.get_version(use_default=False) != "system":
+                else:
                     # Looking up default wine version
                     default_wine = runner.get_runner_version() or {}
                     if "version" in default_wine:
                         logger.debug("Default wine version is %s", default_wine["version"])
-                        params["version"] = "{}-{}".format(
+                        # Set the version to both the is_installed params and
+                        # the script itself so the version gets saved at the
+                        # end of the install.
+                        if self.runner not in self.script:
+                            self.script[self.runner] = {}
+                        params["version"] = self.script[self.runner]["version"] = "{}-{}".format(
                             default_wine["version"],
                             default_wine["architecture"]
                         )
@@ -462,7 +505,7 @@ class ScriptInterpreter(CommandsMixin):
                         logger.error("Failed to get default wine version (got %s)", default_wine)
 
             if not runner.is_installed(**params):
-                logger.debug("Runner %s needs to be installed")
+                logger.info("Runner %s needs to be installed")
                 self.runners_to_install.append(runner)
 
         if self.runner.startswith("wine") and not get_system_wine_version():
@@ -520,11 +563,7 @@ class ScriptInterpreter(CommandsMixin):
 
         # Add steam installation to commands if it's a Steam game
         if self.runner in ("steam", "winesteam"):
-            try:
-                self.steam_data["appid"] = self.script["game"]["appid"]
-            except KeyError:
-                raise ScriptingError("Missing appid for steam game")
-
+            self.steam_data["appid"] = self.script["game"]["appid"]
             if "arch" in self.script["game"]:
                 self.steam_data["arch"] = self.script["game"]["arch"]
 
@@ -600,7 +639,7 @@ class ScriptInterpreter(CommandsMixin):
             path = self._substitute(launcher_value)
             if not os.path.isabs(path) and self.target_path:
                 path = os.path.join(self.target_path, path)
-        self._write_config()
+        self._save_game()
         if path and not os.path.isfile(path) and self.runner not in ("web", "browser"):
             self.parent.set_status(
                 "The executable at path %s can't be found, please check the destination folder.\n"
@@ -608,11 +647,14 @@ class ScriptInterpreter(CommandsMixin):
             )
             logger.warning("No executable found at specified location %s", path)
         else:
-            self.parent.set_status("Installation finished!")
-
+            install_complete_text = (
+                self.script.get("install_complete_text")
+                or "Installation completed!"
+            )
+            self.parent.set_status(install_complete_text)
         self.parent.on_install_finished()
 
-    def _write_config(self):
+    def _save_game(self):
         """Write the game configuration in the DB and config file.
 
         This needs to be unfucked
@@ -692,6 +734,7 @@ class ScriptInterpreter(CommandsMixin):
         yaml_config = yaml.safe_dump(config, default_flow_style=False)
         with open(config_filename, "w") as config_file:
             config_file.write(yaml_config)
+        game.emit("game-installed")
 
     def _substitute_config(self, script_config):
         """Substitute values such as $GAMEDIR in a config dict."""
@@ -730,6 +773,9 @@ class ScriptInterpreter(CommandsMixin):
     def revert(self):
         """Revert installation in case of an error"""
         logger.info("Cancelling installation of %s", self.game_name)
+        if self.runner.startswith("wine"):
+            self.task({"name": "winekill"})
+
         self.cancelled = True
 
         if self.abort_current_task:
@@ -811,7 +857,8 @@ class ScriptInterpreter(CommandsMixin):
         else:
             self.target_path = self._get_steam_game_path()
 
-    def on_steam_game_installed(self, _data, error):
+    @staticmethod
+    def on_steam_game_installed(_data, error):
         """Callback for Steam game installer, mostly for error handling since install progress
         is handled by _monitor_steam_game_install"""
         if error:
@@ -917,63 +964,3 @@ class ScriptInterpreter(CommandsMixin):
             self.parent.set_status("Getting Steam game data")
             self.steam_data["platform"] = "linux"
             self.install_steam_game(steam.steam, is_game_files=True)
-
-    def get_gog_installers(self, gog_service):
-        """Return available installers for a GOG game"""
-
-        self.gog_data = gog_service.get_game_details(self.gogid)
-        if not self.gog_data:
-            logger.warning("Unable to get GOG data for game %s", self.gogid)
-            return []
-
-        # Filter out Mac installers
-        gog_installers = [
-            installer
-            for installer in self.gog_data["downloads"]["installers"]
-            if installer["os"] != "mac"
-        ]
-        available_platforms = {installer["os"] for installer in gog_installers}
-        # If it's a Linux game, also filter out Windows games
-        if "linux" in available_platforms:
-            gog_installers = [
-                installer
-                for installer in gog_installers
-                if installer["os"] != "windows"
-            ]
-
-        # Keep only the english installer until we have locale detection
-        # and / or language selection implemented
-        gog_installers = [
-            installer
-            for installer in gog_installers
-            if installer["language"] == "en"
-        ]
-        return gog_installers
-
-    def get_gog_download_links(self):
-        """Return a list of downloadable links for a GOG game"""
-        gog_service = GogService()
-        if not gog_service.is_available():
-            logger.info("You are not connected to GOG")
-            connect_gog()
-        if not gog_service.is_available():
-            raise UnavailableGame
-        gog_installers = self.get_gog_installers(gog_service)
-        if len(gog_installers) > 1:
-            raise ScriptingError("Don't know how to deal with multiple installers yet.")
-        try:
-            installer = gog_installers[0]
-        except IndexError:
-            raise UnavailableGame
-        download_links = []
-        for game_file in installer.get('files', []):
-            downlink = game_file.get("downlink")
-            if not downlink:
-                logger.error("No download information for %s", installer)
-                continue
-            download_info = gog_service.get_download_info(downlink)
-            for field in ('checksum', 'downlink'):
-                url = download_info[field]
-                logger.info("Adding %s to download links", url)
-                download_links.append(download_info[field])
-        return download_links
