@@ -19,6 +19,7 @@ class Runner:
 
     multiple_versions = False
     platforms = []
+    require_libs = []
     runnable_alone = False
     game_options = []
     runner_options = []
@@ -91,15 +92,12 @@ class Runner:
                 if not os.path.isabs(path):
                     path = os.path.join(self.game_path, path)
                 return path
-
-        if self.game_data.get("directory"):
-            return self.game_data.get("directory")
+        return self.game_path
 
     @property
     def game_path(self):
         """Return the directory where the game is installed."""
-        if self.game_data.get("directory"):
-            return self.game_data.get("directory")
+        return self.game_data.get("directory")
 
     @property
     def working_dir(self):
@@ -201,6 +199,10 @@ class Runner:
             prefer_system_libs=self.system_config.get("prefer_system_libs", True)
         )
 
+    def prelaunch(self):
+        """Run actions before running the game, override this method in runners"""
+        return True
+
     def play(self):
         """Dummy method, must be implemented by derived runners."""
         raise NotImplementedError("Implement the play method in your runner")
