@@ -1,3 +1,4 @@
+"""Steam for Windows service"""
 from lutris.services.steam import SteamSyncer
 
 NAME = "Steam for Windows"
@@ -6,6 +7,7 @@ ONLINE = False
 
 
 class WineSteamSyncer(SteamSyncer):
+    """Sync games with Steam for Windows"""
     platform = "windows"
 
 
