@@ -159,7 +159,7 @@ def fill_missing_platforms():
         if pga_game.get("platform") or not pga_game["runner"]:
             continue
         game = Game(game_id=pga_game["id"])
-        logger.error("Providing missing platorm for game %s", game.slug)
+        logger.error("Providing missing platform for game %s", game.slug)
         game.set_platform_from_runner()
         if game.platform:
             game.save(metadata_only=True)
