@@ -113,6 +113,9 @@ class Downloader:
         if self.referer:
             headers["Referer"] = self.referer
         response = requests.get(self.url, headers=headers, stream=True)
+        if response.status_code != 200:
+            logger.info("%s returned a %s error" % (self.url, response.status_code))
+        response.raise_for_status()
         self.full_size = int(response.headers.get("Content-Length", "").strip() or 0)
         for chunk in response.iter_content(chunk_size=1024 * 1024):
             if not self.file_pointer:
