@@ -1,13 +1,33 @@
 import os
-from lutris.util import datapath, system
+from lutris.settings import RUNTIME_DIR
+from lutris.util import system
 from lutris.util.log import logger
 
 
 class ControllerMapping:
     valid_keys = [
-        "platform", "leftx", "lefty", "rightx", "righty", "a", "b", "back", "dpdown",
-        "dpleft", "dpright", "dpup", "guide", "leftshoulder", "leftstick",
-        "lefttrigger", "rightshoulder", "rightstick", "righttrigger", "start", "x", "y"
+        "platform",
+        "leftx",
+        "lefty",
+        "rightx",
+        "righty",
+        "a",
+        "b",
+        "back",
+        "dpdown",
+        "dpleft",
+        "dpright",
+        "dpup",
+        "guide",
+        "leftshoulder",
+        "leftstick",
+        "lefttrigger",
+        "rightshoulder",
+        "rightstick",
+        "righttrigger",
+        "start",
+        "x",
+        "y",
     ]
 
     def __init__(self, guid, name, mapping):
@@ -21,19 +41,19 @@ class ControllerMapping:
         return self.name
 
     def parse(self):
-        key_maps = self.mapping.split(',')
+        key_maps = self.mapping.split(",")
         for key_map in key_maps:
             if not key_map:
                 continue
-            xinput_key, sdl_key = key_map.split(':')
+            xinput_key, sdl_key = key_map.split(":")
             if xinput_key not in self.valid_keys:
-                logger.warning('Unrecognized key %s', xinput_key)
+                logger.warning("Unrecognized key %s", xinput_key)
                 continue
             self.keys[xinput_key] = sdl_key
 
 
 class GameControllerDB:
-    db_path = os.path.join(datapath.get(), 'controllers/gamecontrollerdb.txt')
+    db_path = os.path.join(RUNTIME_DIR, "gamecontrollerdb/gamecontrollerdb.txt")
 
     def __init__(self):
         if not system.path_exists(self.db_path):
@@ -48,10 +68,10 @@ class GameControllerDB:
         return self.controllers[value]
 
     def parsedb(self):
-        with open(self.db_path, 'r') as db:
+        with open(self.db_path, "r") as db:
             for line in db.readlines():
                 line = line.strip()
-                if not line or line.startswith('#'):
+                if not line or line.startswith("#"):
                     continue
-                guid, name, mapping = line.strip().split(',', 2)
+                guid, name, mapping = line.strip().split(",", 2)
                 self.controllers[guid] = ControllerMapping(guid, name, mapping)
