@@ -136,9 +136,6 @@ def get_formatted_playtime(playtime):
     formatted_time = " and ".join([text for text in (hours_text, minutes_text) if text])
     if formatted_time:
         return formatted_time
-    seconds = int(hours * 3600)
-    if seconds:
-        return "%d seconds" % seconds
     return "No play time recorded"
 
 
